package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````,!D!`#0```!HD0````0`!30`(``)
M`"@`'``;``$``'"TA0``M(4!`+2%`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#`A0``P(4```4```````$`
M`0```-B-``#8C0(`V(T"`#@"``!@$@``!@```````0`"````Y(T``.2-`@#D
MC0(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DV(T`
M`-B-`@#8C0(`*`(``"@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`/D5,JOHT`@+T-(L&1]=>FKIUIMH$
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```D01(``"0`!6`'`8@@``,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4)*0$0`0``!`4,)`$"`
MC,"$```0D!"#"0`(`1"`@$!`P@F`+$"8`D$`(,`@!`D`D``D#I-"0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M`!\````@````(0```"(`````````(P```"4````I`````````"L`````````
M`````"P````M````+@```"\`````````,P```#0````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$8`
M`````````````$<`````````2```````````````````````````````````
M`$D```!*`````````$P`````````3@```%$```!3````````````````````
M`````%0```!8````60```%H`````````6P``````````````70``````````
M````7P```&$```!B````8P```&8```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<5K&IY0
MQ8D%D&&8[Q(!(_FD0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#(.4`?,V+;[3^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#F]Z:?J3K01BWX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;
MLP&+;[S02WUV;^-PF4+NH6H)0]:?(L>H(6)D!WZIG)MBT/J"["SVBVM_FGR'
M\)9\%8PES.\+4?F0=8(-0V9+$#RM.0T7ZEKQIIN3'*/@^TE7DEI2_=+O#V[%
MWQ]\D!#I+=_^2"[%F[;)U;)Q``````````````````````$`````````````
M`"`````=```````````````@````+```````````````(````-("````````
M`````!(```"R`0`````````````2````0`(`````````````$@```!T"````
M`````````!(```#S`P```)`"```````@`!<`;`$`````````````$@```!8"
M`````````````!(```!<`0``?!0!```````2````>`,``!"0`@``````$``8
M`-D!`````````````!(```#[`0`````````````2````,P0```R0`@`$````
M$0`7`(,"`````````````!(```"K!```:#(!`%0"```2``T`S0,``'0D`0`D
M````$@`-`-D"`````````````!(```#A`0`````````````2````E`(`````
M````````$@```+4#```XH`(``````!``&`"8`P`````````````2````V0,`
M``PK`0!<!P``$@`-``T$``!H(0$`T````!(`#0#``P``3"0!`"@````2``T`
M"`(`````````````$@```-0!`````````````!(```!#`0`````````````2
M````<`(`````````````$@```%<$``"X0P$`1`$``!(`#0#L`@``$)`"``0`
M```A`!@`JP$`````````````$@```)4!`````````````!(```#F`P``>$(!
M`$`!```2``T`,@(`````````````$@```*T#```0D`(``````!``%P!-`@``
M```````````2````8P```(P6`0``````$@```!`"`````````````!(```"D
M`@`````````````2````S@$`````````````$@```*8!`````````````!(`
M``#M`@``$)`"``0````A`!@`0@0``#B@`@``````$``8`(T"```@D`(`!```
M`!$`&`!7`P``7$4!``0````2``T`3@$`````````````$@```"H!````````
M`````!(````C!```_$0!`&`````2``T`@@0````J`0`,`0``$@`-`.H!````
M`````````!(```#W`P``,!D!```````2``T`@P``````````````$@```(\`
M`````````````!(```!B`@`````````````2````LP```!B0`@`!````$0`8
M`"L"`````````````!(```#^`P``?$4!``0````1``\`800``!"0`@``````
M$``8`*L"`````````````!(```##`@`````````````2````1@``````````
M````$@```,```````````````!(```!M!```-"$!`#0````2``T`\P``````
M````````$@```#T$```XH`(``````!``&`!U!```/"(!`!`"```2``T`]0(`
M````````````$@```+H!`````````````!(```"D```````````````2````
MT0```!20`@`$````$0`8`.L"```0D`(`!````!$`&``<`0`````````````2
M````.0(`````````````$@```+0#```XH`(``````!``&`"4!```8"D!`(@`
M```2``T`=```````````````$@```'L"`````````````!(```#<````````
M```````2````\0,```"0`@``````$``7`+4"`````````````!(````'`P``
MX(T"``0````1`!0`A@,``.@I`0`8````$@`-`(H!`````````````!(```!W
M`0`````````````2````Y@(``!`7`0`@`@``$@`-`/@``````````````!(`
M``"B!```_$$!`'P````2``T`FP(`````````````$@```%L"````````````
M`!(```!'`@`````````````2````@P$`````````````$@```,L"````````
M`````!(````D`@`````````````2````2@0``)@D`0#(!```$@`-`/T`````
M`````````!(````"`@`````````````2````H0,``+PT`0!8`0``$@`-`%0`
M`````````````!(````Z`0`````````````2````9P,``#@B`0`$````$@`-
M``D!```4%@$``````!(`````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!?7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC
M;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N
M`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S
M=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R
M<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?
M8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`
M;&EB<&5R;"YS;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M
M;&EN=7@M87)M:&8N<V\N,P!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?
M97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E
M;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G
M`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-``````!``$``0`"``,``@`"
M``$``0`"``$``0`"``(``0`"``$``0`"``(``@`!``(``0`!``$``@`"``$`
M`@`!``(``P`#``$``@`!``(``0`"``(``P`#``(``0`"``$``0`!``$``0`"
M``$``0`!``(``0`"``$``0`"``(``0`!``$``0`!``$``@`#``$``0`"``$`
M`@`!``$``0`"``$``0`"``0``0`!``$``0`"``$``@`"``(``@`"``(``0`!
M``(``0`!``$``0`!``$``0!#`P``$````"`````4:6D-```$`,$$````````
M`0`!`"D#```0````(````!1I:0T```,`P00````````!``$`.0,``!``````
M````%&EI#0```@#!!````````/R/`@`5`@``X(T"`!13```0D`(`%$D``!20
M`@`42```&)`"`!0Y```@D`(`%"X```"/`@`6!@``!(\"`!8$```(CP(`%A<`
M``R/`@`6*P``$(\"`!85```4CP(`%CX``!B/`@`66```'(\"`!9;```@CP(`
M%@L``"2/`@`67```*(\"`!9.```LCP(`%D(``#"/`@`6.```-(\"`!9?```X
MCP(`%C0``#R/`@`610``0(\"`!8.``!$CP(`%AL``$B/`@`6,```3(\"`!9*
M``!0CP(`%EH``%2/`@`650``6(\"`!8%``!<CP(`%E8``&"/`@`63P``9(\"
M`!8A``!HCP(`%ET``&R/`@`6$P``<(\"`!8Q``!TCP(`%@(``'B/`@`6!P``
M?(\"`!8<``"`CP(`%B0``(2/`@`69```B(\"`!8I``",CP(`%C8``)"/`@`6
M(@``E(\"`!92``"8CP(`%C<``)R/`@`6'0``H(\"`!9B``"DCP(`%DL``*B/
M`@`69P``K(\"`!8_``"PCP(`%F$``+2/`@`6"0``N(\"`!8F``"\CP(`%D``
M`,"/`@`6"@``Q(\"`!9>``#(CP(`%E```,R/`@`6.@``T(\"`!8G``#4CP(`
M%CT``-B/`@`61P``W(\"`!9E``#@CP(`%A```.2/`@`6#0``Z(\"`!8H``#L
MCP(`%BH``/"/`@`6'@``](\"`!84``#XCP(`%D8```A`+>E9`0#K"("]Z`3@
M+>4$X)_E#N"/X`CPON7<>@$``,:/XA?*C.+<^KSE`,:/XA?*C.+4^KSE`,:/
MXA?*C.+,^KSE`,:/XA?*C.+$^KSE`,:/XA?*C.*\^KSE`,:/XA?*C.*T^KSE
M`,:/XA?*C.*L^KSE`,:/XA?*C.*D^KSE`,:/XA?*C.*<^KSE`,:/XA?*C.*4
M^KSE`,:/XA?*C.*,^KSE`,:/XA?*C.*$^KSE`,:/XA?*C.)\^KSE`,:/XA?*
MC.)T^KSE`,:/XA?*C.)L^KSE`,:/XA?*C.)D^KSE`,:/XA?*C.)<^KSE`,:/
MXA?*C.)4^KSE`,:/XA?*C.),^KSE`,:/XA?*C.)$^KSE`,:/XA?*C.(\^KSE
M`,:/XA?*C.(T^KSE`,:/XA?*C.(L^KSE`,:/XA?*C.(D^KSE`,:/XA?*C.(<
M^KSE`,:/XA?*C.(4^KSE`,:/XA?*C.(,^KSE`,:/XA?*C.($^KSE`,:/XA?*
MC.+\^;SE`,:/XA?*C.+T^;SE`,:/XA?*C.+L^;SE`,:/XA?*C.+D^;SE`,:/
MXA?*C.+<^;SE`,:/XA?*C.+4^;SE`,:/XA?*C.+,^;SE`,:/XA?*C.+$^;SE
M`,:/XA?*C.*\^;SE`,:/XA?*C.*T^;SE`,:/XA?*C.*L^;SE`,:/XA?*C.*D
M^;SE`,:/XA?*C.*<^;SE`,:/XA?*C.*4^;SE`,:/XA?*C.*,^;SE`,:/XA?*
MC.*$^;SE`,:/XA?*C.)\^;SE`,:/XA?*C.)T^;SE`,:/XA?*C.)L^;SE`,:/
MXA?*C.)D^;SE`,:/XA?*C.)<^;SE`,:/XA?*C.)4^;SE`,:/XA?*C.),^;SE
M`,:/XA?*C.)$^;SE`,:/XA?*C.(\^;SE`,:/XA?*C.(T^;SE`,:/XA?*C.(L
M^;SE`,:/XA?*C.(D^;SE`,:/XA?*C.(<^;SE`,:/XA?*C.(4^;SE`,:/XA?*
MC.(,^;SE`,:/XA?*C.($^;SE`,:/XA?*C.+\^+SE`,:/XA?*C.+T^+SE`,:/
MXA?*C.+L^+SE<$`MZ2#03>+@,9_E%`"-Y1`0C>4,((WE%`"-XA`0C>(,((WB
M`#"3Y1PPC>4`,*#CF/__Z[@AG^6X`9_E`A"@X8(+`.NP,9_E`%#3Y0``5>.H
M09\5"0``&FK__^N@(9_E``!0XPP`@N5>```*C$&?Y4/__^L``)3EW?__ZWU7
MP.4``)3EVO__ZP`PH.$``)3EQB/3Y0(@@N/&(\/EU/__ZQ1@G>4$((;B!P%R
MXP-@AN+&,]#E`3"#X\8SP.5%``"*`@&@X57__^LX(9_E$!"=Y2Q!G^444)WE
M`0!5XP`PH.$$`)+E`""1Y00PA.4`((/E%"&?Y0@`@^4$((/E#"&?Y0P@@^4T
M``#:!`!!X@4!@.`,P(/B!."QY0``4>$$X*SE^___&@-0A>(`$*#C`!"-Y08@
MH.$%$8/G#`"4Y=`0G^5X___K`%!0XA(```H,`)3E(___Z[P`G^48$(WB:P``
MZP``4.,/```*#`"4Y0?__^MF___K=#"?Y0`@D^4<,)WE`B`SX``PH.,5```:
M!0"@X2#0C>)P@+WH#`"4Y7___^L`4*#AZ/__Z@@`E.4``%#C`0``"OP&`.OJ
M___J6`"?Y1@0C>)1``#K``!0XP@`A.7D__\*]O__ZF'__^L$4*#CT/__ZO+^
M_^L!`*#C(___Z^"-`@`4%@$`C!8!`!B0`@`4D`(`*)`"``B0`@`\20$`0$D!
M`,0@`0`(1P$`J$8!``"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1#`G^4$P"WE
M#`"?Y0PPG^4`___K7/__ZUQ%`0`0%P$`_$0!`!0PG^44()_E`S"/X`(@D^<`
M`%+C'O\O`?O^_^IX=0$`"`$``!@`G^48,)_E``!3X1[_+P$0,)_E``!3XQ[_
M+P$3_R_A$)`"`!"0`@``````)`"?Y200G^4`,$'@HQ^@X4,1@>#!$+#A'O\O
M`1`PG^4``%/C'O\O`1/_+^$0D`(`$)`"```````00"WI&$"?Y0`PU.4``%/C
M$("]&.#__^L!,*#C`##$Y1"`O>@DD`(`YO__ZO!'+>D`D%#B*@``"K0PG^4`
M@)/E``!8XR@```H`4-GE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"8Y0``
M5.,,```*"&"@X00`H.$%(*#A"1"@X1/__^L``%#C`@``&@4PU.<]`%/C"P``
M"@1`MN4``%3C\___&@0`H.'PA[WH"5"@X0$P]>4``%/C/0!3$_O__QH)4$7@
MYO__Z@A@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__Z@A`H.'K
M___J$)`"`$PQG^7P02WI`%!0XGC03>(`,)/E=#"-Y0`PH.,"```*`##5Y0``
M4^,'```:(#&?Y0`@D^5T,)WE`B`SX``PH.-"```:>-"-XO"!O>A__O_K`$!0
MXO3__PKX<)_E!`"@X='^_^L``%#C*@``"A,PT.438(#B+@!3XP(``!H!,-;E
M``!3X_3__PH3,-#E+@!3XR4```H%`*#AA/[_ZP"`H.$&`*#A@?[_ZP``B.`"
M`(#B;/[_ZP<PH.$`(.#C`1"@XP1@C>4`4(WE`&"@X8;^_^L(((WB!A"@X0,`
MH..[_O_K`0!PXP8`H.$#```*&#"=Y0\Z`^(!"5/C$@``"CO^_^L&`*#A&_[_
MZP0`H.&F_O_K``!0X]3__QH$`*#ANO[_ZP4`H.$<_O_KO___Z@$PUN4N`%/C
MUO__&@(PUN4``%/CQ?__"M+__^JL___KZ___ZB#^_^O@C0(`2$8!`!!`+>EP
MT$WB>#"?Y0`0H.$`0*#A#2"@X0,`H.,`,)/E;#"-Y0`PH..=_O_K``!0XP``
MH!,$```:$#"=Y0\Z`^(*"E/C`0E3$P<```HT,)_E`""3Y6PPG>4"(#/@`#"@
MXP<``!IPT(WB$("]Z`(0H.,$`*#A:?[_ZQ`/;^&@`J#A\?__ZOS]_^O@C0(`
M$$`MZ0!`H.$N_O_K`3!`X@,PA.`#`%3A`R"@,0,``#HD``#J!`!2X0(PH.$A
M```*`C"@X0$04N0O`%'C^/__"@,`5.$;```J`3!#X@,`5.$:```*`"#3Y2\`
M4N/Y__\:`3!#X@,``.H`$-/E`3!#XB\`4>,"```:`P!4X0,@H.'X__\Z!"!"
MX`(P@N(!"E/C!@``B@$ZH.,!((+B!!"@X3P`G^7+_?_K-`"?Y1"`O>@``*#C
M$("]Z`,`5.'G__\:`##4Y2\`4^,"```*$$"]Z!``G^7"_?_J$$"]Z`@`G^6_
M_?_J.)`"`%!&`0`81@$`<$`MZ0':3>((T$WB`3J-X@%0H.'0$)_ET""?Y0`0
MD>4$$(/E`!"@XP!@H.$$$(WBO`"?Y00P@^+"_?_K`,!0XA4``-H(,(WB`4!,
MX@3@@^`$,%[E``!3XR```!H``%3C#0``"@0@H.$O$*#C!`"-X@C^_^L``%#C
M!P``"G0PG^4``)/E+?[_ZP0PH.$$((WB!A"@X1'^_^L%``#J5#"?Y0``D^4E
M_O_K!2"@X080H.&A_?_K`3J-XBP@G^4$,(/B`!"2Y0`@D^4!$#+@`""@XP0`
M`!H!VHWB"-"-XG"`O>@,0*#AWO__ZH3]_^O@C0(`_P\``%1&`0`4D`(`\$<M
MZ0%`H.$`,-'EY"&?Y0C03>(]`%/C`4"!`@!0H.$$`*#A`""2Y00@C>4`(*#C
MJ?W_ZPT0H.$`8*#A!0"@X<;^_^L`D%#B/0``"J+]_^L``%;A-```F@!PG>68
M@9_E!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`
M4A/[__\:!3!#X`(`AN(#`(#@`&"8Y7O]_^L``%#C!P"&YQ8```H`$)WE`""8
MY04`H.$!,-#D`1&2YP``4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C
M``!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!,.+E^___&N0PG^4`
M()/E!#"=Y0(@,^``,*#C,P``&@C0C>+PA[WH`9!)X@$PU.0``%/C`3#IY?O_
M_QKQ___JL("?Y0!PF.4`,)?E``!3XR,```H',*#A!""SY0D0H.$``%+C`9")
MXOK__QH#$('B`1&@X8`PG^4`()/E``!2XP\``!H!(*#C`0"@X0`@@^4^_?_K
M`*!0XMK__PH'$*#A"7&@X0<@H.'Y_/_K`*"(Y0$PB>(`(*#C`R&*YP"0C>6F
M___J!P"@X17]_^L``%#C`*"@X0``B.7*__\*"7&@X?+__^H#D*#A"!"@X^#_
M_^H"_?_KX(T"`!"0`@`HD`(`$$`MZ0C03>)$0)_E``"4Y8K]_^L``)3EB/W_
MZS0PG^4T()_E-!"?Y3_]_^L``)3E@OW_ZR@PG^4`P*#C)""?Y200G^4($(WH
M3_W_ZPC0C>(0@+WH%)`"`,2$`0!\%`$`9$8!`#A)`0!H,@$`@$8!`!PPG^40
M0"WI``"3Y6_]_^L00+WH##"?Y0P@G^4,$)_E)?W_ZA20`@#$A`$`?!0!`&1&
M`0`P0"WI`MI-XAS03>*L()_E`CJ-XA0P@^(`()+E`""#Y0`@H./\_/_KE!"?
MY90PG^64()_E\`#-X0$0H.,,`(WB"OW_ZP$:C>(!*J#C$!"!X@P`C>+2_/_K
M`$!0X@!0H+,)``"Z`0"$XM_\_^L`4%#B!0``"@$:C>($(*#A$!"!XJ#\_^L`
M,*#C!##%YP(ZC>(H()_E%#"#X@`0DN4`()/E`1`RX``@H.,#```:!0"@X0+:
MC>(<T(WB,("]Z*;\_^O@C0(`I$8!`)A&`0`!$```RO__ZO!/+>E"W4WB!-!-
MXN`AG^5!/8WB`%"@X0%@H.'4`9_E$!"-XCPP@^(`()+E`""#Y0`@H./J_?_K
M+Q"@XP!`H.$%`*#AR_S_ZP``4.,.```*I`&?Y040H.$)___K!0"@X4$]C>*(
M(9_E/#"#X@`0DN4`()/E`1`RX``@H.-;```:0MV-X@30C>+PC[WH!0"@X;+\
M_^MD$9_E`("@X08`H.'G_/_K`+!0XNC__PH`,-OE3*&?Y4R1G^4``%/C/'&?
MY7Q@C>(R```*``!4XP0```H+$*#A!`"@X4/\_^L``%#C(@``"@L`H.&<_/_K
M`2!`X@(PB^`"(-OG+P!2XP4``!H`P*#C`,##Y0$@<^4!`$#B+P!2X_K__PH!
M,(CB``"#X`$*4./)__^J"3"@X0$JH.,!$*#C!@"@X0A0C>4$H(WE`+"-Y93\
M_^L0((WB!A"@X0,`H./)_/_K``!0XP,``!H@,)WE#SH#X@()4^,4```*!Q"@
MX0``H..Q_/_K``!0XP"PH.&Q__\*`##;Y0``4^/,__\:``!4XP(```H`,-3E
M+@!3XP(```I<L)_E`0"@X]C__^H!,-3E``!3X^O__PKX___J`1"@XP8`H.&6
M_/_K``!0X^7__QH<`)_E!A"@X:?^_^L&`*#A(_S_ZYO__^HD_/_KX(T"`*A&
M`0"T1@$`Q$8!`%!&`0#(1@$`&$8!```PT.4``%/C'O\O`0$@@.(O`%/C`@"@
M`0$PTN0``%/C^O__&A[_+^$`,%#B`P``"@`PT^4``%/C````"A'^_^H``)_E
M"/S_ZAA&`0`P0"WI--!-XF3DG^5D-)_E","-X@`PD^4L,(WE`#"@XP\`ONA0
M1)_E4%2?Y0\`K.@/`+[H#P"LZ``PGN6P,,SA!!"-X@0`H.%._?_K``!0XPP`
M``H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#
MY/O__QKM___J]$.?Y>Q3G^4$$(WB!`"@X3K]_^L``%#C#```"@00G>4`()7E
M`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^JH
M0Y_EG%.?Y000C>($`*#A)OW_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``
M4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZEQ#G^5,4Y_E!!"-
MX@0`H.$2_?_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKM___J$$.?Y?Q2G^4$$(WB!`"@X?[\_^L`
M`%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``
M4N,$((/D^___&NW__^K$0I_EK%*?Y000C>($`*#AZOS_ZP``4.,,```*!!"=
MY0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:
M[?__ZGA"G^5<4I_E!!"-X@0`H.'6_/_K``!0XPP```H$$)WE`""5Y0$Q@N`$
M`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J+$*?Y0Q2
MG^4$$(WB!`"@X<+\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"
MY_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^K@09_EO%&?Y000C>($`*#A
MKOS_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($
M()/E``!2XP0@@^3[__\:[?__ZI1!G^5L49_E!!"-X@0`H.&:_/_K``!0XPP`
M``H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#
MY/O__QKM___J2$&?Y1Q1G^4$$(WB!`"@X8;\_^L``%#C#```"@00G>4`()7E
M`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^H$
M$(WB^`"?Y73\_^L`$%#B`0``"MP`G^68_?_K!!"-XN``G^5M_/_K`!!0X@$`
M``K4`)_ED?W_ZP00C>+,`)_E9OS_ZP`04.(,```*G`"?Y8K]_^NX$)_EB`"?
MY8?]_^MH,)_E`""3Y2PPG>4"(#/@`#"@XQ,``!HTT(WB,("]Z`00C>*,`)_E
M5/S_ZP`04.("```*6`"?Y7C]_^OL___J=!"?Y0H@H.,9`(WB=?O_ZP``4./F
M__\:-`"?Y2,0C>)N_?_KXO__ZNWZ_^O0A`$`X(T"`-!&`0`0D`(`W$8!`.1&
M`0#P1@$`^$8!``A'`0"H1@$`%$<!`"!'`0`L1P$`M$8!`#A'`0!,1P$`'$8!
M`&!'`0"01P$`<$<!`(1'`0`00"WI"-!-XFQ`G^5L,)_E``"4Y0`PD^4$,(WE
M`#"@XP$`<.,'```*4#"?Y0`@D^4$,)WE`B`SX``PH.,-```:"-"-XA"`O>@T
M`)_E#1"@X1K\_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#``"$Y>O_
M_^JY^O_K")`"`."-`@`41P$`$$`MZ9;Z_^N/^O_K``!0XP``D!40@+WH<$`M
MZ1C03>+L,)_E`%"@X1`0C>+D`)_E`#"3Y10PC>4`,*#C_?O_ZP!`4.(.```*
M`##4Y0``4^,+```*!1"@X77Z_^L``%#C$@``"J@PG^4`()/E%#"=Y0(@,^``
M,*#C)```&AC0C>)P@+WHB#"?Y0`@D^44,)WE`B`SX``PH.,%$*`!=`"?!1H`
M`!H8T(WB<$"]Z`G]_^H%`*#AOOK_ZP!@H.$$`*#AN_K_ZP``AN`"`(#BIOK_
MZT0PG^4`(.#C`1"@XQ@`C>D`4(WE-#"?Y0!`H.&_^O_K'#"?Y0`@D^44,)WE
M`B`SX``PH.,$$*`!"`"?!>3__PIQ^O_KX(T"`)1'`0#$1@$`R$8!`/!/+>D"
MV4WB_-!-XO`VG^7P%I_E`BF-X@`0D>7T$(+E`!"@X_0@@N(`<*#A!P"3Z(1`
MC>(,X(/B)%"#X@<`A.B<P(WB#P"^Z)!`C>(/`*SH`P">Z`,`C.@'`)7H!P"$
MZ!@0C>*@!I_EJ?O_ZP!`4.("```*`##4Y0``4^,$`0`:+OK_ZR?Z_^L`0%#B
MW0``"@!0E.4``%7CV0``"@4`H.%Z^O_K@`"@X0$`@.)E^O_K`"#5Y0``4N,`
M8*#A"P``"DB&G^4&0*#A!`"@X0`@C>4(,*#A`"#@XP$0H.-Z^O_K`2#UY0)`
MA.(``%+C]?__&AP&G^6@4(WB`@``Z@0`E>0``%#C#0``"A@0C>*`^__K`$!0
MXOC__PH`,-3E``!3X_7__PH$_/_K``!0X_+__PH$`*#A'/K_ZP!`4.(4```:
M`%"@XX20C>+X,(WB!3&#X'1`$^4``%3C#```"@&`A>((@8G@`##4Y0``4^,'
M```*!`"@X?#[_^L!4(7B``!0XSL``!H$0)CD``!4X_3__QH`0*#C!`"@X3SZ
M_^MTE9_E`*"@X08`H.$X^O_K``"*X`&K@.($H(KB"@"@X2'Z_^M4-9_E`"#@
MXP$0H.,(,(WE#&"-Y40UG^4`0(WE!)"-Y0"`H.$X^O_K!QV@XP@`H.$^^O_K
M`0!PXP,``!HO^O_K`!"0Y1$`4>.7```:&""-X@@0H.$#`*#C</K_ZP!04.(8
M```*^!2?Y0`PE^7T))_E``"1Y0$0H.,`@(WE/?K_ZP!@H.,".8WBN"2?Y?0P
M@^(`$)+E`""3Y0$0,N``(*#C)@$`&@8`H.$"V8WB_-"-XO"/O>@$`*#AR_G_
MZP!`4.*P__\*PO__ZB@PG>4/.@/B`0E3X^+__QHP0)WEI_G_ZP``5.'>__\:
M*#"=Y8,[H.&C.Z#A!PU3X]G__QH*`*#AX/G_ZQ@0C>(`8*#A6`2?Y0_[_^L`
M`%#C@0``"@!`E^6Q^?_K`!"@X00`H.$/_?_K`*!0XGH```H*`*#AX_G_ZP,`
M4.,`0*#A"P``F@0`0.(8%)_E``"*X'_Y_^L``%#C!0``&@0`5./%```*!$"*
MX`4P5.4O`%/CP0``"O!#G^4`,)3E`0!SXV<```H``%/C=```"MP3G^7<`Y_E
M%/S_Z\3Y_^O4<Y_EU#.?Y0`@X.,!$*#C\(#-X0QPC>7$HY_E"`"-Y08`H.'/
M^?_K#@``ZLKY_^L`,)#E$0!3XQ```!JT^?_K`5"%X@HPH.$$(*#A`1"@XQ!P
MC>4,4(WE`,"@X08`H.$`$XWHO_G_ZP<=H.,&`*#AQ?G_ZP$`<.,`0*#AZO__
M"@@`H.%:^?_K&`.?Y080H.'N^__K!@"@X;S^_^N/___J!4"@X9!@C>+X,(WB
M!#&#X&@`$^4``%#C*@``"@%0A.(%@8;@`P``Z@0`F.0``%#C)```"@%0A>(8
M$(WBL_K_ZP5`H.$`,%#B]O__"@`PT^4``%/C\___"E+Y_^L`4%#B#/__&N?_
M_^JP`I_E`#"7Y=`BG^4``)#E!!"-Y0"`C>4!$*#CJOG_ZP!@H.-K___JEO[_
MZP(YC>)D(I_E]#"#X@`0DN4`()/E`1`RX``@H..1```:!`"@X0+9C>+\T(WB
M\$^]Z#?Y_^H-`*#C7/G_ZW12G^53(*#C`&"@X?;^_^H`H)?E@O__ZD@"G^48
M$(WBAOK_ZP``4.,``(0%"```"@`PT.4``%/C,`!3$P$PH!,`,*`#`3"@$P`P
MA`4`,(05BO__&@H`H.$`$*#C0?G_ZP!`4.*%__\*`E"@XP`PX.,1(.#C`%"-
MY3'Y_^L&(*#C]!"-X@0`H.'T^/_K]##=Y0``4^,"```:]3#=Y4,`4^-````*
M`#"@XP`@H.,`,(WE!`"@X0`PH.,A^?_K5@0`ZP!0H.$"``#J]!"-X@4`H.%P
M!`#K`BF@X_00C>($`*#AWOC_ZP`@4.+V___*!`"@X8+Y_^L%$*#AM`"-XK4$
M`.OX,(WB,*!#XBRQG^6S4(WB"D"@X3%P0^(!(/7E!`"@X0LPH.$`((WE`1"@
MXP`@X.,P^?_K!0!7X0)`A.+U__\:)"&?Y0`0H.,,((WE\!#-Y2@QG^4`(.#C
M`1"@XP8`H.$(H(WE\(#-X2+Y_^MG___J!$"7Y0``5.,Z__\*!`"@X0WY_^L#
M`%#C-O__F@0`0.+L$)_E``"$X*KX_^L``%#C!*"@`2___^KV,-WE00!3X[O_
M_QKW,-WE0P!3X[C__QKX,-WE2`!3X[7__QKY,-WE10!3X[+__QH`,.#C!`"@
MX3D@X.,`4(WEU?C_Z_00C>($`*#A*2"@XYCX_^MH()_E]#"-X@@PC>4,((WE
M;#"?Y0`@X.,!$*#C!@"@X020C>4`@(WE\_C_ZSC__^JL^/_K](0!`."-`@"H
M1@$`K$<!`!Q&`0!01@$`P$<!`+1'`0`@D`(`!$@!`%A(`0!@2`$`")`"`)!'
M`0`41P$`.$D!`(!(`0"02`$`R$<!`*1'`0!P2`$`:$@!`'!`+>D(T$WB$$*?
MY1`RG^4``)3E`#"3Y00PC>4`,*#C'?G_ZP!0H.$``)3E&OG_ZV@@U>4-$*#A
M`#"@X>0!G^5I(,/EV_G_ZP``4.,"```*`##0Y3$`4^-7```*<_S_ZP``E.4,
M^?_KO!&?Y0,PH.,!(*#CHOC_ZP!04.(*```*``"4Y03Y_^L0,)7EG"&?Y0`0
MD^5_^/_K$#"5Y0`PD^4(,)/E`043XU```!H``)3E^?C_ZW@1G^4#,*#C`2"@
MXX_X_^L`4%#B"@``"F0!G^4-$*#AM_G_ZP!@4.(Z```*``"4Y>SX_^L0,)7E
M!B"@X0`0D^5G^/_K/&&?Y0``E.7E^/_K`%"@X0``E.7B^/_K*!&?Y0$@H...
M^/_K("&?Y0`0H.$%`*#A6OC_ZP``E.79^/_K`""@XPT0H.$`,*#A``&?Y6D@
MP^6:^?_K``!0XP!`H.$(`(;E#P``"@<=H.,$`*#ABOC_ZP$@@.(1`%#C`0!2
M$P`PH.$C``"*H#"?Y0`@D^4$,)WE`B`SX``PH.,<```:"-"-XG"`O>@$`);E
MO_W_ZP``4.,`0*#A"`"&Y>G__QJ0`)_E;_C_ZP$PT.4``%/CI?__"J/__^IH
M8)_E``"4Y;#X_^L$();E$#"5Y0`0DN4``)/E6_K_Z\+__^H``)3EJ/C_ZQ`P
ME>4`$)/E;_C_ZZC__^H3^/_K!""6Y3@`G^4`$)+E!""@X5;X_^L4D`(`X(T"
M`/A&`0"D2`$`J$@!`+!(`0"T1@$`*)`"`+1(`0#,2`$`J$8!`-1(`0#X2`$`
M/#&?Y?!`+>D`<%#B#-!-X@`PD^4$,(WE`#"@XS,```H`,-?E``!3XS````KY
M^?_K`$"@X0`PU.4``%/C!0``"@$@A.(O`%/C`D"@`0$PTN0``%/C^O__&NA@
MG^4`4%?B`5"@$P`PEN4!`'/C(P``"@``4^,`4*`#`5`%$@``5>,'```:N#"?
MY0`@D^4$,)WE`B`SX``PH.,H```:#-"-XO"`O>@`,-?E``!3X_3__PJ4$)_E
M!""@XP0`H.%2^/_K``!0X^[__QIT,)_E`""3Y00PG>4"(#/@`#"@XQ<``!H'
M`*#A#-"-XO!`O>A/^?_J6`"?Y<#W_^L`0*#AS/__ZDP`G^4-$*#A%?G_ZP``
M4.,``(8%VO__"@`PT.4``%/C,`!3$P`PH`,!,*`3`#"&!=/__PH!,*#C`#"&
MY<[__^JP]__KX(T"``B0`@#`1P$`&$8!`!1'`0``````R#N?Y?!/+>FCWTWB
M0!"`XH!@@.(-(*#A`#"3Y80RC>4`,*#C`%"@XP3`$>4(X!'E"!"!XBPTH.'_
M/`/B+#R#X0Q$H.$,/(/A_T@$XC[/O^8$,(/A!@!1X0#`@N4$4(+E"#""Y0Q0
M@N40((+B[?__&@C`3>)^[XWB`#"@XPQ`H.$(8+SE<""4Y4B0E.5T$)3E3("4
MY1APE.4<4)3E"2`BX`1`G.4($"'@!R`BX`8@(N`%$"'@!!`AX*)/H.&!0(3A
M`B"2X`0@@N$.`%SA\"C,X>G__QKX*I_E`%"0Y0`0G>4$H)#E(,"0Y0(0D>`,
M$)'@I<V@X1!`D.4(<)#E&&"0Y8K"C.$,D)#EA<*,X0'`G.`&$"3@)^&@X0<0
M`>`)[X[A!A`AX`'`G.`'CX[A"!"=Y0C@).`"$)'@)9&@X07@#N`$X"[@!A"1
MX`J?B>$%GXGA#A"1X!#@G>4)H"C@`N">X`R@"N`$X)[@"*`JX`J@GN`8X)WE
M[!V!X`+@GN`(X)[@;($IX`&`".`)@"C@"(">X"#@G>7AK8K@`N">X&$1H.$)
MD)[@;.$AX`K@#N!LX2[@#I"9X"C@G>7JC8C@`N">X&S!CN!JX2'@".`.X`'@
M+N`.P)S@,."=Y>B=B>`"X)[@:(&@X0$0GN!JX2C@">`.X.G-C.!JX2[@#A"1
MX.SM@>`X$)WE`A"1X&H1@>!IH2C@#*`*X`B@*N`*$)'@0*"=Y6S!H.$"H)K@
M"(":X&FA+.`.H`K@[AV!X&FA*N`*@)C@X:V(X$B`G>4"@)C@:8&(X&Z1+.`!
MD`G@#)`IX`F`F.!0D)WE81&@X0*0F>`,P)G@;I$AX`J0">#JC8C@;I$IX`G`
MG.#HG8S@6,"=Y0+`G.!NP8S@:N$AX`C@#N`!X"[@#L"<X&#@G>5H@:#A`N">
MX`$0GN!JX2C@">`.X.G-C.!JX2[@#A"1X.SM@>!H$)WE`A"1X&H1@>!IH2C@
M#*`*X`B@*N`*$)'@<*"=Y6S!H.$"H)K@"(":X&FA+.`.H`K@[AV!X&FA*N`*
M@)C@X;V(X'B`G>6@H)WE`H"8X&F!B.!ND2S@`9`)X`R0*>`)D)C@@("=Y6$1
MH.$"@)C@#,"8X&Z!(>`+@`C@ZYV)X&Z!*.`(P)S@Z8V,X(C`G>4"P)S@;L&,
MX&OA(>`)X`[@`>`NX`[`G."0X)WE:9&@X0+@GN`!$)[@:^$IX`C@#N#HS8S@
M:^$NX`X0D>#L[8'@F!"=Y0(@D>!KL8+@:"$IX`P@`N`)("+@`K";X!@HG^5L
MP:#A`J":X.X=B^`)H)K@J+"=Y6B1+.`.D"G@"9":X`*PF^!HL8O@L*"=Y6Z!
M+.`!@"C@X9V)X`B`F^!A$:#A`J":X`R@FN"XL)WE;L$AX.F-B.`)P"S@#,":
MX`*PF^#HK8S@;N&+X&G!(>#`L)WE",`LX`S@GN!H@:#A`K";X,C`G>4!L)O@
M:1$HX.KMCN`*$"'@`1";X`+`G.#NO8'@:9&,X&H1*.#0P)WE#A`AX`&0F>!N
MX:#A`L"<X-@0G>4(@)S@:L$NX`O`+.`,@)C@`A"1X.N=B>#@P)WE:J&!X&L1
M+N`)$"'@Z8V(X`&@FN!ID:#A`L"<X.@0G>4.X)S@:\$IX`C`+.`,X)[@`A"1
MX.BMBN#PP)WE:[&!X&@1*>`*$"'@ZNV.X`&PF^!JH:#A`L"<X/@0G>4)D)S@
M:,$JX`[`+.`,D)G@`A"1X.Z]B^!H@8'@;A$JX`L0(>`!@)C@`!&=Y>N=B>`"
M$)'@:[&@X6[!*^`*H)'@"!&=Y0G`+.`,H)K@`A"1X.F-B.`0P9WE;N&!X&D1
M*^`($"'@Z*V*X`'@GN!H@:#A`L"<X!@1G>4+L)S@:<$HX.KMCN`*P"S@#+";
MX`(0D>!JP2C@:1&!X.Z=B^`@L9WE#L`LX`P0D>!NX:#A`K";X.G-@>`(@)O@
M:A$NX"BQG>4)$"'@`1"8X`*PF^!JH8O@:8$NX#"QG>7L'8'@#(`HX`B`FN!L
MH:#A`K";X.'-B.`.X)O@:8$JX#BQG>4!@"C@".">X`(@F^!ID8+@82$JX`P@
M(N#LC8[@`I"9X$#AG>7`)9_E;,&@X0+@GN`*X)[@8:&,X6&Q#.`(H`K@"Z"*
MX0K@GN!(H9WEZ)V)X`*PFN!HH8SAZ>V.X&&QB^`)H`K@:1&@X6B1#.`)D(KA
M4*&=Y0N0F>`"H)K@#,":X&BA@>%HL0'@#J`*X`N@BN$,P)K@6*&=Y>Z=B>`"
ML)K@;J&!X6BQB^`)H`K@Z8V,X&G!H.%ND0'@"9"*X6"AG>4+D)G@`J":X`$0
MFN!NH8SA;K$,X`B@"N`+H(KA`:":X&@1G>7HG8G@`K"1X&@1C.'IK8K@;K&+
MX`D0`>!IX:#A:)$,X`D0@>%PD9WE"Q"1X`*0F>`,P)G@:)&.X6BQ#N`*D`G@
M"Y")X0R0F>!XP9WEZAV!X`*PG.!HL8O@:H&.X>&=B>!AP:#A`8`(X&H1#N`!
M$(CA"Q"1X.F]@>"`$9WE:H$,X`(0D>`.$)'@:N&,X0G@#N`(X([A`>">X(@1
MG>7KC8[@`A"1X&JA@>!I$8SA:^&@X0L0`>!IL0S@"Q"!X0J@D>"0$9WE:;$.
MX`(0D>`,$)'@Z,V*X&FACN$(H`K@"Z"*X0&@FN"8$9WE:+$.X`(0D>!ID8'@
M:!&.X0P0`>#LK8K@"Q"!X0D0D>#JO8'@H!&=Y6S!H.$"$)'@#A"1X&CAC.%H
MD0S@"N`.X`G@CN$!D)[@J!&=Y>N=B>`"X)'@:A&,X6CACN`+$`'@:X&@X6JQ
M#.`+$('A#N"1X+`1G>5JL0C@`A"1X`P0D>#IS8[@:N&(X0G@#N`+X([A`1">
MX+CAG>5IL0C@`N">X&KACN#LK8'@:1&(X0P0`>`+$('A#N"1X,`1G>5LP:#A
M`A"1X`@0D>!I@8SA:;$,X`J`".`+@(CA!#"`Y0&`F.#($9WEZNV.X`(0D>!I
MD8'@:A&,X6JQ#.`.$`'@"Q"!X0F0D>#0$9WE[HV(X`(0D>!NX:#A#!"1X&K!
MCN%JL0[@",`,X`O`C.$!P)S@V!&=Y>B=B>`"()'@:!&.X6BQ#N`)$`'@:J&"
MX`L0@>'0(I_E"A"1X."AG>7IS8S@`J":X&F1H.'HL9WE#N":X.RM@>!H$2G@
M#!`AX`'@GN`"L)O@;!$IX&B!B^#PL9WE"A`AX.KMCN`!@)C@:J&@X0*PF^`)
ML)O@^!&=Y6R1*N`.D"G@"9";X`(0D>#NC8C@`+*=Y6S!@>!N$2K@"!`AX.B=
MB>`!P)S@:(&@X0*PF^`*L)O@"!*=Y6ZA*.`)H"K@"J";X`(0D>#IS8S@$+*=
MY6[A@>!I$2C@#!`AX.RMBN`!X)[@;,&@X0*PF^`(L)O@&!*=Y6F!+.`*@"C@
M"(";X`(0D>#J[8[@(+*=Y6F1@>!J$2S@#A`AX.Z-B.`!D)G@;N&@X0*PF^`,
ML)O@*!*=Y6K!+N`(P"S@#,";X`(0D>#HG8G@,+*=Y6JA@>!H$2[@"1`AX.G-
MC.`!H)K@:9&@X0*PF^`.L)O@.!*=Y6CA*>`,X"[@#N";X`(0D>#LK8K@0+*=
MY6B!@>!L$2G@"A`AX.KMCN`!@)C@:J&@X0*PF^`)L)O@2!*=Y6R1*N`.D"G@
M"9";X`(0D>#NC8C@4+*=Y6S!@>!N$2K@"!`AX.B=B>`!P)S@:(&@X0*PF^`*
ML)O@6!*=Y6ZA*.`)H"K@"J";X`(0D>#IS8S@8+*=Y6[A@>!I$2C@#!`AX.RM
MBN`!X)[@;,&@X0*PF^`(L)O@:8$LX.KMCN`*@"C@"(";X.Z-B.!H$IWE:&&&
MX`(0D>!ID8'@&&"`Y7`2G>5J82S@#F`FX`:0F>`"$)'@#!"1X.C-B>!NX:#A
M;$&$X&IA+N`00(#E>$*=Y0A@)N`&$)'@`B"4X`4@DN!JH8+@:"$NX.P=@>`,
M("+@(,"0Y0*@FN#A+8K@!Q"1X`S@GN`,,(#E%#"`Y1PP@.4`((#E"!"`Y2#@
M@.4D,(#E'#"?Y0`@D^6$,IWE`B`SX``PH.,!```:H]^-XO"/O>BV]/_KX(T"
M`)EY@EJAZ]ENW+P;C];!8LH00"WI@`"@X]+T_^L.>Y_M`""@XP![@.T->Y_M
M>""`Y0)[@.T,>Y_M!'N`[0Q[G^T&>X#M#'N?[0A[@.T,>Y_M"GN`[0Q[@.T0
M@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````
M````````\$<MZ0*0H.$H,)#E+""0Y8GA@^`#`%[A`,"@XP(PW.``4*#A,""0
MY0%`H.$T$)#ER0^@X0(``"H!,)+B`R"@X0`0H>*I/J#A@#&#X0(PD^"@'J'@
M>`"5Y3B`A>(``%#C*."%Y2S`A>4P,(7E-!"%Y1\``!H_`%GC+@``VD"02>(I
M8Z#A`7"&X@=SA.`(,*#A0."$X@#`E.4$`)3E"!"4Y0P@E.400(3B#@!4X0#`
M@^4$`(/E"!"#Y0P@@^40,(/B\___&@4`H.&T_/_K!P!4X>W__QH&;6;@!I.)
MX`D@H.$'$*#A"`"@X4+T_^MXD(7E\(>]Z$!P8.('`%GA"7"@L0``B.`'(*#A
M!!"@X3GT_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'D$G@!T"$X)K\_^O.
M___J!'"@X>;__^KP02WI.'"!XB@@D>4P8)'E,H^_YJ(QH.$_,`/B`2"#X@%`
MH.$X`%+C?Q#@XP!0H.$V;[_F`@"'X`,0Q^<\``#:0"!BX@`0H..`]/_K!`"@
MX8+\_^L'`*#A.""@XP`0H.-Z]/_K!`"@X7!@A.5T@(3E>OS_ZP,PU.4$`*#A
M`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%
M,,7E"#"4Y2,TH.$&,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,T
MH.$*,,7E$#"4Y0LPQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4
MY0\PQ>4C,-3E$##%Y;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WH
MW?/_ZC@@8N(`$*#C0_3_Z\?__^KP1RWI`'"@X4A@G^5(4)_E!F"/X`50C^`%
M8$;@`8"@X0*0H.&U\__K1F&PX?"'O0@`0*#C!#"5Y`D@H.$($*#A!P"@X0%`
MA.(S_R_A!`!6X??__QKPA[WHR$@!`,!(`0`>_R_A"#"?Y0,PC^``,)/EU_/_
MZIA*`0`(0"WI"("]Z`$``@`[````/@````L````^````$````#X````E````
M/@```#,````^`````P```#X````&````/@```!0````^````#@```#X````-
M````/@```"0````^````$@```#X````G````/@````(````^````&````#X`
M```)````/@````H````^```````````````O=&UP`````"X```!005)?5$U0
M1$E2``!414U01$E2`%1-4`!54T52`````%5315).04U%`````"5S+R5S````
M+P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`%!!
M4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S``!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(`
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%
M04X]```Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S
M)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R
M`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M
M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)
M3TX`````,2XP-3(```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``979A;"`G97AE
M8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T
M(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM
M>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92!O<B!L87-T.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D
M8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M
M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D
M<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU
M;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(
M+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S
M=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA
M9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N
M<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@
M)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U
M-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A
M;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*
M)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H
M+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]
M*3L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M
M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A
M<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q
M<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B
M=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A
M('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E
M("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN
M;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN
M960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI3
M2$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M
M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?
M34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD
M=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR
M96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S
M+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&)U
M9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H
M)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M<&YA;64B.B`D
M(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O
M;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA
M;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@`````!!&`0`81@$``````!Q&`0`@1@$`*$8!`*Q&`0`P
M1@$``````#1&`0`\1@$``````#L````^````"P```#X````0````/@```"4`
M```^````,P```#X````#````/@````8````^````%````#X````.````/@``
M``T````^````)````#X````2````/@```"<````^`````@```#X````8````
M/@````D````^````"@```#X``````````````'R3_W\!````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````'!H!
M`/09`0```````0```!D#```!````*0,```$````Y`P```0```$,#```,````
M_!,!``T```!T10$`&0```-B-`@`;````!````!H```#<C0(`'`````0```#U
M_O]OM`$!``4```#8"P$`!@```%@%`0`*````RP0```L````0````%0``````
M```#````](X"``(```#X`0``%````!$````7````!!(!`!$```#4$0$`$@``
M`#`````3````"````!X````(````^___;P$```#^__]O=!$!`/___V\#````
M\/__;Z00`0``````````````````````````````````````````````````
M``````````````#DC0(````````````(%`$`"!0!``@4`0`(%`$`"!0!``@4
M`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!
M``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`
M"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(
M%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4
M`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!
M``@4`0````````````````#_____1$D!`$=#0SH@*%)A<W!B:6%N(#$P+C,N
M,"TQ,2MR<&DQ*2`Q,"XS+C``02X```!A96%B:0`!)`````4V``8&"`$)`0H"
M$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN
M<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M``````L````!`````@```%0!`0!4`0``&0```````````````0`````````3
M````!P````(```!P`0$`<`$``"0```````````````0`````````)@````<`
M```"````E`$!`)0!```@```````````````$`````````#0```#V__]O`@``
M`+0!`0"T`0``I`,```4`````````!`````0````^````"P````(```!8!0$`
M6`4``(`&```&`````0````0````0````1@````,````"````V`L!`-@+``#+
M!``````````````!`````````$X```#___]O`@```*00`0"D$```T`````4`
M`````````@````(```!;````_O__;P(```!T$0$`=!$``&`````&`````P``
M``0`````````:@````D````"````U!$!`-01```P````!0`````````$````
M"````',````)````0@````02`0`$$@``^`$```4````6````!`````@```!\
M`````0````8```#\$P$`_!,```P```````````````0`````````=P````$`
M```&````"!0!``@4```(`P`````````````$````!````((````!````!@``
M`!`7`0`0%P``9"X`````````````"`````````"(`````0````8```!T10$`
M=$4```@```````````````0`````````C@````$````"````?$4!`'Q%```X
M0``````````````$`````````)8````!``!P@@```+2%`0"TA0``"`````T`
M````````!`````````"A`````0````(```"\A0$`O(4```0`````````````
M``0`````````JP````X````#````V(T"`-B-```$```````````````$````
M!````+<````/`````P```-R-`@#<C0``!```````````````!`````0```##
M`````0````,```#@C0(`X(T```0```````````````0`````````T`````8`
M```#````Y(T"`.2-```0`0``!@`````````$````"````-D````!`````P``
M`/2.`@#TC@``#`$`````````````!`````0```#>`````0````,`````D`(`
M`)```!````````````````0`````````Y`````@````#````$)`"`!"0```H
M$``````````````(`````````.D````!````,``````````0D```)@``````
M`````````0````$```#R`````P``<```````````-I```"\`````````````
M``$``````````0````,``````````````&60```"`0`````````````!````
$````````
